# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.crm.lists.api_client import ApiClient
from hubspot.crm.lists.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class MembershipsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def add(self, list_id, request_body, **kwargs):  # noqa: E501
        """Add Records to a List  # noqa: E501

        Add the records provided to the list. Records that do not exist or that are already members of the list are ignored.  This endpoint only works for lists that have a `processingType` of `MANUAL` or `SNAPSHOT`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.add(list_id, request_body, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the `MANUAL` or `SNAPSHOT` list. (required)
        :type list_id: str
        :param request_body: (required)
        :type request_body: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: MembershipsUpdateResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.add_with_http_info(list_id, request_body, **kwargs)  # noqa: E501

    def add_with_http_info(self, list_id, request_body, **kwargs):  # noqa: E501
        """Add Records to a List  # noqa: E501

        Add the records provided to the list. Records that do not exist or that are already members of the list are ignored.  This endpoint only works for lists that have a `processingType` of `MANUAL` or `SNAPSHOT`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.add_with_http_info(list_id, request_body, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the `MANUAL` or `SNAPSHOT` list. (required)
        :type list_id: str
        :param request_body: (required)
        :type request_body: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(MembershipsUpdateResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["list_id", "request_body"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method add" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'list_id' is set
        if self.api_client.client_side_validation and local_var_params.get("list_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `list_id` when calling `add`")  # noqa: E501
        # verify the required parameter 'request_body' is set
        if self.api_client.client_side_validation and local_var_params.get("request_body") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `request_body` when calling `add`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "list_id" in local_var_params:
            path_params["listId"] = local_var_params["list_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "request_body" in local_var_params:
            body_params = local_var_params["request_body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PUT", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "MembershipsUpdateResponse",
        }

        return self.api_client.call_api(
            "/crm/v3/lists/{listId}/memberships/add",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def add_all_from_list(self, list_id, source_list_id, **kwargs):  # noqa: E501
        """Add All Records from a Source List to a Destination List  # noqa: E501

        Add all of the records from a *source list* (specified by the `sourceListId`) to a *destination list* (specified by the `listId`). Records that are already members of the *destination list* will be ignored. The *destination* and *source list* IDs must be different. The *destination* and *source lists* must contain records of the same type (e.g. contacts, companies, etc.).  This endpoint only works for *destination lists* that have a `processingType` of `MANUAL` or `SNAPSHOT`. The *source list* can have any `processingType`.  This endpoint only supports a `sourceListId` for lists with less than 100,000 memberships.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.add_all_from_list(list_id, source_list_id, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the `MANUAL` or `SNAPSHOT` *destination list*, which the *source list* records are added to. (required)
        :type list_id: str
        :param source_list_id: The **ILS ID** of the *source list* to grab the records from, which are then added to the *destination list*. (required)
        :type source_list_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.add_all_from_list_with_http_info(list_id, source_list_id, **kwargs)  # noqa: E501

    def add_all_from_list_with_http_info(self, list_id, source_list_id, **kwargs):  # noqa: E501
        """Add All Records from a Source List to a Destination List  # noqa: E501

        Add all of the records from a *source list* (specified by the `sourceListId`) to a *destination list* (specified by the `listId`). Records that are already members of the *destination list* will be ignored. The *destination* and *source list* IDs must be different. The *destination* and *source lists* must contain records of the same type (e.g. contacts, companies, etc.).  This endpoint only works for *destination lists* that have a `processingType` of `MANUAL` or `SNAPSHOT`. The *source list* can have any `processingType`.  This endpoint only supports a `sourceListId` for lists with less than 100,000 memberships.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.add_all_from_list_with_http_info(list_id, source_list_id, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the `MANUAL` or `SNAPSHOT` *destination list*, which the *source list* records are added to. (required)
        :type list_id: str
        :param source_list_id: The **ILS ID** of the *source list* to grab the records from, which are then added to the *destination list*. (required)
        :type source_list_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["list_id", "source_list_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method add_all_from_list" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'list_id' is set
        if self.api_client.client_side_validation and local_var_params.get("list_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `list_id` when calling `add_all_from_list`")  # noqa: E501
        # verify the required parameter 'source_list_id' is set
        if self.api_client.client_side_validation and local_var_params.get("source_list_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `source_list_id` when calling `add_all_from_list`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "list_id" in local_var_params:
            path_params["listId"] = local_var_params["list_id"]  # noqa: E501
        if "source_list_id" in local_var_params:
            path_params["sourceListId"] = local_var_params["source_list_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/crm/v3/lists/{listId}/memberships/add-from/{sourceListId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def add_and_remove(self, list_id, membership_change_request, **kwargs):  # noqa: E501
        """Add and/or Remove Records from a List  # noqa: E501

        Add and/or remove records that have already been created in the system to and/or from a list.  This endpoint only works for lists that have a `processingType` of `MANUAL` or `SNAPSHOT`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.add_and_remove(list_id, membership_change_request, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the `MANUAL` or `SNAPSHOT` list. (required)
        :type list_id: str
        :param membership_change_request: (required)
        :type membership_change_request: MembershipChangeRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: MembershipsUpdateResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.add_and_remove_with_http_info(list_id, membership_change_request, **kwargs)  # noqa: E501

    def add_and_remove_with_http_info(self, list_id, membership_change_request, **kwargs):  # noqa: E501
        """Add and/or Remove Records from a List  # noqa: E501

        Add and/or remove records that have already been created in the system to and/or from a list.  This endpoint only works for lists that have a `processingType` of `MANUAL` or `SNAPSHOT`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.add_and_remove_with_http_info(list_id, membership_change_request, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the `MANUAL` or `SNAPSHOT` list. (required)
        :type list_id: str
        :param membership_change_request: (required)
        :type membership_change_request: MembershipChangeRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(MembershipsUpdateResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["list_id", "membership_change_request"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method add_and_remove" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'list_id' is set
        if self.api_client.client_side_validation and local_var_params.get("list_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `list_id` when calling `add_and_remove`")  # noqa: E501
        # verify the required parameter 'membership_change_request' is set
        if self.api_client.client_side_validation and local_var_params.get("membership_change_request") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `membership_change_request` when calling `add_and_remove`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "list_id" in local_var_params:
            path_params["listId"] = local_var_params["list_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "membership_change_request" in local_var_params:
            body_params = local_var_params["membership_change_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PUT", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "MembershipsUpdateResponse",
        }

        return self.api_client.call_api(
            "/crm/v3/lists/{listId}/memberships/add-and-remove",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_lists(self, object_type_id, record_id, **kwargs):  # noqa: E501
        """Get lists record is member of  # noqa: E501

        For given record provide lists this record is member of.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_lists(object_type_id, record_id, async_req=True)
        >>> result = thread.get()

        :param object_type_id: Object type id of the record (required)
        :type object_type_id: str
        :param record_id: Id of the record (required)
        :type record_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ApiCollectionResponseRecordListMembershipNoPaging
        """
        kwargs["_return_http_data_only"] = True
        return self.get_lists_with_http_info(object_type_id, record_id, **kwargs)  # noqa: E501

    def get_lists_with_http_info(self, object_type_id, record_id, **kwargs):  # noqa: E501
        """Get lists record is member of  # noqa: E501

        For given record provide lists this record is member of.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_lists_with_http_info(object_type_id, record_id, async_req=True)
        >>> result = thread.get()

        :param object_type_id: Object type id of the record (required)
        :type object_type_id: str
        :param record_id: Id of the record (required)
        :type record_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ApiCollectionResponseRecordListMembershipNoPaging, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["object_type_id", "record_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_lists" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_type_id' is set
        if self.api_client.client_side_validation and local_var_params.get("object_type_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_type_id` when calling `get_lists`")  # noqa: E501
        # verify the required parameter 'record_id' is set
        if self.api_client.client_side_validation and local_var_params.get("record_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `record_id` when calling `get_lists`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_type_id" in local_var_params:
            path_params["objectTypeId"] = local_var_params["object_type_id"]  # noqa: E501
        if "record_id" in local_var_params:
            path_params["recordId"] = local_var_params["record_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "ApiCollectionResponseRecordListMembershipNoPaging",
        }

        return self.api_client.call_api(
            "/crm/v3/lists/records/{objectTypeId}/{recordId}/memberships",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_page(self, list_id, **kwargs):  # noqa: E501
        """Fetch List Memberships Ordered by ID  # noqa: E501

        Fetch the memberships of a list in order sorted by the `recordId` of the records in the list.  The `recordId`s are sorted in *ascending* order if an `after` offset or no offset is provided. If only a `before` offset is provided, then the records are sorted in *descending* order.  The `after` offset parameter will take precedence over the `before` offset in a case where both are provided.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_page(list_id, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the list. (required)
        :type list_id: str
        :param after: The paging offset token for the page that comes `after` the previously requested records.  If provided, then the records in the response will be the records following the offset, sorted in *ascending* order. Takes precedence over the `before` offset.
        :type after: str
        :param before: The paging offset token for the page that comes `before` the previously requested records.  If provided, then the records in the response will be the records preceding the offset, sorted in *descending* order.
        :type before: str
        :param limit: The number of records to return in the response. The maximum `limit` is 250.
        :type limit: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ApiCollectionResponseJoinTimeAndRecordId
        """
        kwargs["_return_http_data_only"] = True
        return self.get_page_with_http_info(list_id, **kwargs)  # noqa: E501

    def get_page_with_http_info(self, list_id, **kwargs):  # noqa: E501
        """Fetch List Memberships Ordered by ID  # noqa: E501

        Fetch the memberships of a list in order sorted by the `recordId` of the records in the list.  The `recordId`s are sorted in *ascending* order if an `after` offset or no offset is provided. If only a `before` offset is provided, then the records are sorted in *descending* order.  The `after` offset parameter will take precedence over the `before` offset in a case where both are provided.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_page_with_http_info(list_id, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the list. (required)
        :type list_id: str
        :param after: The paging offset token for the page that comes `after` the previously requested records.  If provided, then the records in the response will be the records following the offset, sorted in *ascending* order. Takes precedence over the `before` offset.
        :type after: str
        :param before: The paging offset token for the page that comes `before` the previously requested records.  If provided, then the records in the response will be the records preceding the offset, sorted in *descending* order.
        :type before: str
        :param limit: The number of records to return in the response. The maximum `limit` is 250.
        :type limit: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ApiCollectionResponseJoinTimeAndRecordId, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["list_id", "after", "before", "limit"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_page" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'list_id' is set
        if self.api_client.client_side_validation and local_var_params.get("list_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `list_id` when calling `get_page`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "list_id" in local_var_params:
            path_params["listId"] = local_var_params["list_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("after") is not None:  # noqa: E501
            query_params.append(("after", local_var_params["after"]))  # noqa: E501
        if local_var_params.get("before") is not None:  # noqa: E501
            query_params.append(("before", local_var_params["before"]))  # noqa: E501
        if local_var_params.get("limit") is not None:  # noqa: E501
            query_params.append(("limit", local_var_params["limit"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "ApiCollectionResponseJoinTimeAndRecordId",
        }

        return self.api_client.call_api(
            "/crm/v3/lists/{listId}/memberships",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_page_ordered_by_added_to_list_date(self, list_id, **kwargs):  # noqa: E501
        """Fetch List Memberships Ordered by Added to List Date  # noqa: E501

        Fetch the memberships of a list in order sorted by the time the records were added to the list.  The `recordId`s are sorted in *ascending* order if an `after` offset or no offset is provided. If only a `before` offset is provided, then the records are sorted in *descending* order.  The `after` offset parameter will take precedence over the `before` offset in a case where both are provided.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_page_ordered_by_added_to_list_date(list_id, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the list. (required)
        :type list_id: str
        :param after: The paging offset token for the page that comes `after` the previously requested records.  If provided, then the records in the response will be the records following the offset, sorted in *ascending* order. Takes precedence over the `before` offset.
        :type after: str
        :param before: The paging offset token for the page that comes `before` the previously requested records.  If provided, then the records in the response will be the records preceding the offset, sorted in *descending* order.
        :type before: str
        :param limit: The number of records to return in the response. The maximum `limit` is 250.
        :type limit: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ApiCollectionResponseJoinTimeAndRecordId
        """
        kwargs["_return_http_data_only"] = True
        return self.get_page_ordered_by_added_to_list_date_with_http_info(list_id, **kwargs)  # noqa: E501

    def get_page_ordered_by_added_to_list_date_with_http_info(self, list_id, **kwargs):  # noqa: E501
        """Fetch List Memberships Ordered by Added to List Date  # noqa: E501

        Fetch the memberships of a list in order sorted by the time the records were added to the list.  The `recordId`s are sorted in *ascending* order if an `after` offset or no offset is provided. If only a `before` offset is provided, then the records are sorted in *descending* order.  The `after` offset parameter will take precedence over the `before` offset in a case where both are provided.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_page_ordered_by_added_to_list_date_with_http_info(list_id, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the list. (required)
        :type list_id: str
        :param after: The paging offset token for the page that comes `after` the previously requested records.  If provided, then the records in the response will be the records following the offset, sorted in *ascending* order. Takes precedence over the `before` offset.
        :type after: str
        :param before: The paging offset token for the page that comes `before` the previously requested records.  If provided, then the records in the response will be the records preceding the offset, sorted in *descending* order.
        :type before: str
        :param limit: The number of records to return in the response. The maximum `limit` is 250.
        :type limit: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ApiCollectionResponseJoinTimeAndRecordId, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["list_id", "after", "before", "limit"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_page_ordered_by_added_to_list_date" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'list_id' is set
        if self.api_client.client_side_validation and local_var_params.get("list_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `list_id` when calling `get_page_ordered_by_added_to_list_date`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "list_id" in local_var_params:
            path_params["listId"] = local_var_params["list_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("after") is not None:  # noqa: E501
            query_params.append(("after", local_var_params["after"]))  # noqa: E501
        if local_var_params.get("before") is not None:  # noqa: E501
            query_params.append(("before", local_var_params["before"]))  # noqa: E501
        if local_var_params.get("limit") is not None:  # noqa: E501
            query_params.append(("limit", local_var_params["limit"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "ApiCollectionResponseJoinTimeAndRecordId",
        }

        return self.api_client.call_api(
            "/crm/v3/lists/{listId}/memberships/join-order",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def remove(self, list_id, request_body, **kwargs):  # noqa: E501
        """Remove Records from a List  # noqa: E501

        Remove the records provided from the list. Records that do not exist or that are not members of the list are ignored.  This endpoint only works for lists that have a `processingType` of `MANUAL` or `SNAPSHOT`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.remove(list_id, request_body, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the `MANUAL` or `SNAPSHOT` list. (required)
        :type list_id: str
        :param request_body: (required)
        :type request_body: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: MembershipsUpdateResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.remove_with_http_info(list_id, request_body, **kwargs)  # noqa: E501

    def remove_with_http_info(self, list_id, request_body, **kwargs):  # noqa: E501
        """Remove Records from a List  # noqa: E501

        Remove the records provided from the list. Records that do not exist or that are not members of the list are ignored.  This endpoint only works for lists that have a `processingType` of `MANUAL` or `SNAPSHOT`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.remove_with_http_info(list_id, request_body, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the `MANUAL` or `SNAPSHOT` list. (required)
        :type list_id: str
        :param request_body: (required)
        :type request_body: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(MembershipsUpdateResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["list_id", "request_body"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method remove" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'list_id' is set
        if self.api_client.client_side_validation and local_var_params.get("list_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `list_id` when calling `remove`")  # noqa: E501
        # verify the required parameter 'request_body' is set
        if self.api_client.client_side_validation and local_var_params.get("request_body") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `request_body` when calling `remove`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "list_id" in local_var_params:
            path_params["listId"] = local_var_params["list_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "request_body" in local_var_params:
            body_params = local_var_params["request_body"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PUT", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "MembershipsUpdateResponse",
        }

        return self.api_client.call_api(
            "/crm/v3/lists/{listId}/memberships/remove",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def remove_all(self, list_id, **kwargs):  # noqa: E501
        """Delete All Records from a List  # noqa: E501

        Remove **all** of the records from a list. ***Note:*** *The list is not deleted.*  This endpoint only works for lists that have a `processingType` of `MANUAL` or `SNAPSHOT`.  This endpoint only supports lists that have less than 100,000 memberships.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.remove_all(list_id, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the `MANUAL` or `SNAPSHOT` list. (required)
        :type list_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.remove_all_with_http_info(list_id, **kwargs)  # noqa: E501

    def remove_all_with_http_info(self, list_id, **kwargs):  # noqa: E501
        """Delete All Records from a List  # noqa: E501

        Remove **all** of the records from a list. ***Note:*** *The list is not deleted.*  This endpoint only works for lists that have a `processingType` of `MANUAL` or `SNAPSHOT`.  This endpoint only supports lists that have less than 100,000 memberships.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.remove_all_with_http_info(list_id, async_req=True)
        >>> result = thread.get()

        :param list_id: The **ILS ID** of the `MANUAL` or `SNAPSHOT` list. (required)
        :type list_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["list_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method remove_all" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'list_id' is set
        if self.api_client.client_side_validation and local_var_params.get("list_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `list_id` when calling `remove_all`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "list_id" in local_var_params:
            path_params["listId"] = local_var_params["list_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/crm/v3/lists/{listId}/memberships",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



# coding: utf-8

"""
    Schemas

    The CRM uses schemas to define how custom objects should store and represent information in the HubSpot CRM. Schemas define details about an object's type, properties, and associations. The schema can be uniquely identified by its **object type ID**.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.schemas.configuration import Configuration


class Option(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"hidden": "bool", "display_order": "int", "description": "str", "label": "str", "value": "str"}

    attribute_map = {"hidden": "hidden", "display_order": "displayOrder", "description": "description", "label": "label", "value": "value"}

    def __init__(self, hidden=None, display_order=None, description=None, label=None, value=None, local_vars_configuration=None):  # noqa: E501
        """Option - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._hidden = None
        self._display_order = None
        self._description = None
        self._label = None
        self._value = None
        self.discriminator = None

        self.hidden = hidden
        if display_order is not None:
            self.display_order = display_order
        if description is not None:
            self.description = description
        self.label = label
        self.value = value

    @property
    def hidden(self):
        """Gets the hidden of this Option.  # noqa: E501

        Hidden options will not be displayed in HubSpot.  # noqa: E501

        :return: The hidden of this Option.  # noqa: E501
        :rtype: bool
        """
        return self._hidden

    @hidden.setter
    def hidden(self, hidden):
        """Sets the hidden of this Option.

        Hidden options will not be displayed in HubSpot.  # noqa: E501

        :param hidden: The hidden of this Option.  # noqa: E501
        :type hidden: bool
        """
        if self.local_vars_configuration.client_side_validation and hidden is None:  # noqa: E501
            raise ValueError("Invalid value for `hidden`, must not be `None`")  # noqa: E501

        self._hidden = hidden

    @property
    def display_order(self):
        """Gets the display_order of this Option.  # noqa: E501

        Options are displayed in order starting with the lowest positive integer value. Values of -1 will cause the option to be displayed after any positive values.  # noqa: E501

        :return: The display_order of this Option.  # noqa: E501
        :rtype: int
        """
        return self._display_order

    @display_order.setter
    def display_order(self, display_order):
        """Sets the display_order of this Option.

        Options are displayed in order starting with the lowest positive integer value. Values of -1 will cause the option to be displayed after any positive values.  # noqa: E501

        :param display_order: The display_order of this Option.  # noqa: E501
        :type display_order: int
        """

        self._display_order = display_order

    @property
    def description(self):
        """Gets the description of this Option.  # noqa: E501

        A description of the option.  # noqa: E501

        :return: The description of this Option.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Option.

        A description of the option.  # noqa: E501

        :param description: The description of this Option.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def label(self):
        """Gets the label of this Option.  # noqa: E501

        A human-readable option label that will be shown in HubSpot.  # noqa: E501

        :return: The label of this Option.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this Option.

        A human-readable option label that will be shown in HubSpot.  # noqa: E501

        :param label: The label of this Option.  # noqa: E501
        :type label: str
        """
        if self.local_vars_configuration.client_side_validation and label is None:  # noqa: E501
            raise ValueError("Invalid value for `label`, must not be `None`")  # noqa: E501

        self._label = label

    @property
    def value(self):
        """Gets the value of this Option.  # noqa: E501

        The internal value of the option, which must be used when setting the property value through the API.  # noqa: E501

        :return: The value of this Option.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this Option.

        The internal value of the option, which must be used when setting the property value through the API.  # noqa: E501

        :param value: The value of this Option.  # noqa: E501
        :type value: str
        """
        if self.local_vars_configuration.client_side_validation and value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Option):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Option):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Forms

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.forms.configuration import Configuration


class FormDisplayOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"render_raw_html": "bool", "css_class": "str", "theme": "str", "submit_button_text": "str", "style": "FormStyle"}

    attribute_map = {"render_raw_html": "renderRawHtml", "css_class": "cssClass", "theme": "theme", "submit_button_text": "submitButtonText", "style": "style"}

    def __init__(self, render_raw_html=None, css_class=None, theme=None, submit_button_text=None, style=None, local_vars_configuration=None):  # noqa: E501
        """FormDisplayOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._render_raw_html = None
        self._css_class = None
        self._theme = None
        self._submit_button_text = None
        self._style = None
        self.discriminator = None

        self.render_raw_html = render_raw_html
        if css_class is not None:
            self.css_class = css_class
        self.theme = theme
        self.submit_button_text = submit_button_text
        self.style = style

    @property
    def render_raw_html(self):
        """Gets the render_raw_html of this FormDisplayOptions.  # noqa: E501

        Whether the form will render as raw HTML as opposed to inside an iFrame.  # noqa: E501

        :return: The render_raw_html of this FormDisplayOptions.  # noqa: E501
        :rtype: bool
        """
        return self._render_raw_html

    @render_raw_html.setter
    def render_raw_html(self, render_raw_html):
        """Sets the render_raw_html of this FormDisplayOptions.

        Whether the form will render as raw HTML as opposed to inside an iFrame.  # noqa: E501

        :param render_raw_html: The render_raw_html of this FormDisplayOptions.  # noqa: E501
        :type render_raw_html: bool
        """
        if self.local_vars_configuration.client_side_validation and render_raw_html is None:  # noqa: E501
            raise ValueError("Invalid value for `render_raw_html`, must not be `None`")  # noqa: E501

        self._render_raw_html = render_raw_html

    @property
    def css_class(self):
        """Gets the css_class of this FormDisplayOptions.  # noqa: E501

          # noqa: E501

        :return: The css_class of this FormDisplayOptions.  # noqa: E501
        :rtype: str
        """
        return self._css_class

    @css_class.setter
    def css_class(self, css_class):
        """Sets the css_class of this FormDisplayOptions.

          # noqa: E501

        :param css_class: The css_class of this FormDisplayOptions.  # noqa: E501
        :type css_class: str
        """

        self._css_class = css_class

    @property
    def theme(self):
        """Gets the theme of this FormDisplayOptions.  # noqa: E501

        The theme used for styling the input fields. This will not apply if the form is added to a HubSpot CMS page.  # noqa: E501

        :return: The theme of this FormDisplayOptions.  # noqa: E501
        :rtype: str
        """
        return self._theme

    @theme.setter
    def theme(self, theme):
        """Sets the theme of this FormDisplayOptions.

        The theme used for styling the input fields. This will not apply if the form is added to a HubSpot CMS page.  # noqa: E501

        :param theme: The theme of this FormDisplayOptions.  # noqa: E501
        :type theme: str
        """
        if self.local_vars_configuration.client_side_validation and theme is None:  # noqa: E501
            raise ValueError("Invalid value for `theme`, must not be `None`")  # noqa: E501
        allowed_values = ["default_style", "canvas", "linear", "round", "sharp", "legacy"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and theme not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `theme` ({0}), must be one of {1}".format(theme, allowed_values))  # noqa: E501

        self._theme = theme

    @property
    def submit_button_text(self):
        """Gets the submit_button_text of this FormDisplayOptions.  # noqa: E501

        The text displayed on the form submit button.  # noqa: E501

        :return: The submit_button_text of this FormDisplayOptions.  # noqa: E501
        :rtype: str
        """
        return self._submit_button_text

    @submit_button_text.setter
    def submit_button_text(self, submit_button_text):
        """Sets the submit_button_text of this FormDisplayOptions.

        The text displayed on the form submit button.  # noqa: E501

        :param submit_button_text: The submit_button_text of this FormDisplayOptions.  # noqa: E501
        :type submit_button_text: str
        """
        if self.local_vars_configuration.client_side_validation and submit_button_text is None:  # noqa: E501
            raise ValueError("Invalid value for `submit_button_text`, must not be `None`")  # noqa: E501

        self._submit_button_text = submit_button_text

    @property
    def style(self):
        """Gets the style of this FormDisplayOptions.  # noqa: E501


        :return: The style of this FormDisplayOptions.  # noqa: E501
        :rtype: FormStyle
        """
        return self._style

    @style.setter
    def style(self, style):
        """Sets the style of this FormDisplayOptions.


        :param style: The style of this FormDisplayOptions.  # noqa: E501
        :type style: FormStyle
        """
        if self.local_vars_configuration.client_side_validation and style is None:  # noqa: E501
            raise ValueError("Invalid value for `style`, must not be `None`")  # noqa: E501

        self._style = style

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FormDisplayOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FormDisplayOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Forms

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.forms.configuration import Configuration


class FormStyle(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "label_text_size": "str",
        "legal_consent_text_color": "str",
        "font_family": "str",
        "legal_consent_text_size": "str",
        "background_width": "str",
        "help_text_size": "str",
        "submit_font_color": "str",
        "label_text_color": "str",
        "submit_alignment": "str",
        "submit_size": "str",
        "help_text_color": "str",
        "submit_color": "str",
    }

    attribute_map = {
        "label_text_size": "labelTextSize",
        "legal_consent_text_color": "legalConsentTextColor",
        "font_family": "fontFamily",
        "legal_consent_text_size": "legalConsentTextSize",
        "background_width": "backgroundWidth",
        "help_text_size": "helpTextSize",
        "submit_font_color": "submitFontColor",
        "label_text_color": "labelTextColor",
        "submit_alignment": "submitAlignment",
        "submit_size": "submitSize",
        "help_text_color": "helpTextColor",
        "submit_color": "submitColor",
    }

    def __init__(
        self,
        label_text_size=None,
        legal_consent_text_color=None,
        font_family=None,
        legal_consent_text_size=None,
        background_width=None,
        help_text_size=None,
        submit_font_color=None,
        label_text_color=None,
        submit_alignment=None,
        submit_size=None,
        help_text_color=None,
        submit_color=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """FormStyle - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._label_text_size = None
        self._legal_consent_text_color = None
        self._font_family = None
        self._legal_consent_text_size = None
        self._background_width = None
        self._help_text_size = None
        self._submit_font_color = None
        self._label_text_color = None
        self._submit_alignment = None
        self._submit_size = None
        self._help_text_color = None
        self._submit_color = None
        self.discriminator = None

        self.label_text_size = label_text_size
        self.legal_consent_text_color = legal_consent_text_color
        self.font_family = font_family
        self.legal_consent_text_size = legal_consent_text_size
        self.background_width = background_width
        self.help_text_size = help_text_size
        self.submit_font_color = submit_font_color
        self.label_text_color = label_text_color
        self.submit_alignment = submit_alignment
        self.submit_size = submit_size
        self.help_text_color = help_text_color
        self.submit_color = submit_color

    @property
    def label_text_size(self):
        """Gets the label_text_size of this FormStyle.  # noqa: E501

          # noqa: E501

        :return: The label_text_size of this FormStyle.  # noqa: E501
        :rtype: str
        """
        return self._label_text_size

    @label_text_size.setter
    def label_text_size(self, label_text_size):
        """Sets the label_text_size of this FormStyle.

          # noqa: E501

        :param label_text_size: The label_text_size of this FormStyle.  # noqa: E501
        :type label_text_size: str
        """
        if self.local_vars_configuration.client_side_validation and label_text_size is None:  # noqa: E501
            raise ValueError("Invalid value for `label_text_size`, must not be `None`")  # noqa: E501

        self._label_text_size = label_text_size

    @property
    def legal_consent_text_color(self):
        """Gets the legal_consent_text_color of this FormStyle.  # noqa: E501

          # noqa: E501

        :return: The legal_consent_text_color of this FormStyle.  # noqa: E501
        :rtype: str
        """
        return self._legal_consent_text_color

    @legal_consent_text_color.setter
    def legal_consent_text_color(self, legal_consent_text_color):
        """Sets the legal_consent_text_color of this FormStyle.

          # noqa: E501

        :param legal_consent_text_color: The legal_consent_text_color of this FormStyle.  # noqa: E501
        :type legal_consent_text_color: str
        """
        if self.local_vars_configuration.client_side_validation and legal_consent_text_color is None:  # noqa: E501
            raise ValueError("Invalid value for `legal_consent_text_color`, must not be `None`")  # noqa: E501

        self._legal_consent_text_color = legal_consent_text_color

    @property
    def font_family(self):
        """Gets the font_family of this FormStyle.  # noqa: E501

          # noqa: E501

        :return: The font_family of this FormStyle.  # noqa: E501
        :rtype: str
        """
        return self._font_family

    @font_family.setter
    def font_family(self, font_family):
        """Sets the font_family of this FormStyle.

          # noqa: E501

        :param font_family: The font_family of this FormStyle.  # noqa: E501
        :type font_family: str
        """
        if self.local_vars_configuration.client_side_validation and font_family is None:  # noqa: E501
            raise ValueError("Invalid value for `font_family`, must not be `None`")  # noqa: E501

        self._font_family = font_family

    @property
    def legal_consent_text_size(self):
        """Gets the legal_consent_text_size of this FormStyle.  # noqa: E501

          # noqa: E501

        :return: The legal_consent_text_size of this FormStyle.  # noqa: E501
        :rtype: str
        """
        return self._legal_consent_text_size

    @legal_consent_text_size.setter
    def legal_consent_text_size(self, legal_consent_text_size):
        """Sets the legal_consent_text_size of this FormStyle.

          # noqa: E501

        :param legal_consent_text_size: The legal_consent_text_size of this FormStyle.  # noqa: E501
        :type legal_consent_text_size: str
        """
        if self.local_vars_configuration.client_side_validation and legal_consent_text_size is None:  # noqa: E501
            raise ValueError("Invalid value for `legal_consent_text_size`, must not be `None`")  # noqa: E501

        self._legal_consent_text_size = legal_consent_text_size

    @property
    def background_width(self):
        """Gets the background_width of this FormStyle.  # noqa: E501

          # noqa: E501

        :return: The background_width of this FormStyle.  # noqa: E501
        :rtype: str
        """
        return self._background_width

    @background_width.setter
    def background_width(self, background_width):
        """Sets the background_width of this FormStyle.

          # noqa: E501

        :param background_width: The background_width of this FormStyle.  # noqa: E501
        :type background_width: str
        """
        if self.local_vars_configuration.client_side_validation and background_width is None:  # noqa: E501
            raise ValueError("Invalid value for `background_width`, must not be `None`")  # noqa: E501

        self._background_width = background_width

    @property
    def help_text_size(self):
        """Gets the help_text_size of this FormStyle.  # noqa: E501

          # noqa: E501

        :return: The help_text_size of this FormStyle.  # noqa: E501
        :rtype: str
        """
        return self._help_text_size

    @help_text_size.setter
    def help_text_size(self, help_text_size):
        """Sets the help_text_size of this FormStyle.

          # noqa: E501

        :param help_text_size: The help_text_size of this FormStyle.  # noqa: E501
        :type help_text_size: str
        """
        if self.local_vars_configuration.client_side_validation and help_text_size is None:  # noqa: E501
            raise ValueError("Invalid value for `help_text_size`, must not be `None`")  # noqa: E501

        self._help_text_size = help_text_size

    @property
    def submit_font_color(self):
        """Gets the submit_font_color of this FormStyle.  # noqa: E501

          # noqa: E501

        :return: The submit_font_color of this FormStyle.  # noqa: E501
        :rtype: str
        """
        return self._submit_font_color

    @submit_font_color.setter
    def submit_font_color(self, submit_font_color):
        """Sets the submit_font_color of this FormStyle.

          # noqa: E501

        :param submit_font_color: The submit_font_color of this FormStyle.  # noqa: E501
        :type submit_font_color: str
        """
        if self.local_vars_configuration.client_side_validation and submit_font_color is None:  # noqa: E501
            raise ValueError("Invalid value for `submit_font_color`, must not be `None`")  # noqa: E501

        self._submit_font_color = submit_font_color

    @property
    def label_text_color(self):
        """Gets the label_text_color of this FormStyle.  # noqa: E501

          # noqa: E501

        :return: The label_text_color of this FormStyle.  # noqa: E501
        :rtype: str
        """
        return self._label_text_color

    @label_text_color.setter
    def label_text_color(self, label_text_color):
        """Sets the label_text_color of this FormStyle.

          # noqa: E501

        :param label_text_color: The label_text_color of this FormStyle.  # noqa: E501
        :type label_text_color: str
        """
        if self.local_vars_configuration.client_side_validation and label_text_color is None:  # noqa: E501
            raise ValueError("Invalid value for `label_text_color`, must not be `None`")  # noqa: E501

        self._label_text_color = label_text_color

    @property
    def submit_alignment(self):
        """Gets the submit_alignment of this FormStyle.  # noqa: E501

          # noqa: E501

        :return: The submit_alignment of this FormStyle.  # noqa: E501
        :rtype: str
        """
        return self._submit_alignment

    @submit_alignment.setter
    def submit_alignment(self, submit_alignment):
        """Sets the submit_alignment of this FormStyle.

          # noqa: E501

        :param submit_alignment: The submit_alignment of this FormStyle.  # noqa: E501
        :type submit_alignment: str
        """
        if self.local_vars_configuration.client_side_validation and submit_alignment is None:  # noqa: E501
            raise ValueError("Invalid value for `submit_alignment`, must not be `None`")  # noqa: E501
        allowed_values = ["left", "right", "center"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and submit_alignment not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `submit_alignment` ({0}), must be one of {1}".format(submit_alignment, allowed_values))  # noqa: E501

        self._submit_alignment = submit_alignment

    @property
    def submit_size(self):
        """Gets the submit_size of this FormStyle.  # noqa: E501

          # noqa: E501

        :return: The submit_size of this FormStyle.  # noqa: E501
        :rtype: str
        """
        return self._submit_size

    @submit_size.setter
    def submit_size(self, submit_size):
        """Sets the submit_size of this FormStyle.

          # noqa: E501

        :param submit_size: The submit_size of this FormStyle.  # noqa: E501
        :type submit_size: str
        """
        if self.local_vars_configuration.client_side_validation and submit_size is None:  # noqa: E501
            raise ValueError("Invalid value for `submit_size`, must not be `None`")  # noqa: E501

        self._submit_size = submit_size

    @property
    def help_text_color(self):
        """Gets the help_text_color of this FormStyle.  # noqa: E501

          # noqa: E501

        :return: The help_text_color of this FormStyle.  # noqa: E501
        :rtype: str
        """
        return self._help_text_color

    @help_text_color.setter
    def help_text_color(self, help_text_color):
        """Sets the help_text_color of this FormStyle.

          # noqa: E501

        :param help_text_color: The help_text_color of this FormStyle.  # noqa: E501
        :type help_text_color: str
        """
        if self.local_vars_configuration.client_side_validation and help_text_color is None:  # noqa: E501
            raise ValueError("Invalid value for `help_text_color`, must not be `None`")  # noqa: E501

        self._help_text_color = help_text_color

    @property
    def submit_color(self):
        """Gets the submit_color of this FormStyle.  # noqa: E501

          # noqa: E501

        :return: The submit_color of this FormStyle.  # noqa: E501
        :rtype: str
        """
        return self._submit_color

    @submit_color.setter
    def submit_color(self, submit_color):
        """Sets the submit_color of this FormStyle.

          # noqa: E501

        :param submit_color: The submit_color of this FormStyle.  # noqa: E501
        :type submit_color: str
        """
        if self.local_vars_configuration.client_side_validation and submit_color is None:  # noqa: E501
            raise ValueError("Invalid value for `submit_color`, must not be `None`")  # noqa: E501

        self._submit_color = submit_color

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FormStyle):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FormStyle):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.settings.users.api.roles_api import RolesApi
from hubspot.settings.users.api.teams_api import TeamsApi
from hubspot.settings.users.api.users_api import UsersApi



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.oauth.api.access_tokens_api import AccessTokensApi
from hubspot.oauth.api.refresh_tokens_api import RefreshTokensApi
from hubspot.oauth.api.tokens_api import TokensApi



# coding: utf-8

# flake8: noqa
"""
    Properties

    All HubSpot objects store data in default and custom properties. These endpoints provide access to read and modify object properties in HubSpot.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.crm.properties.models.batch_input_property_create import BatchInputPropertyCreate
from hubspot.crm.properties.models.batch_input_property_name import BatchInputPropertyName
from hubspot.crm.properties.models.batch_read_input_property_name import BatchReadInputPropertyName
from hubspot.crm.properties.models.batch_response_property import BatchResponseProperty
from hubspot.crm.properties.models.batch_response_property_with_errors import BatchResponsePropertyWithErrors
from hubspot.crm.properties.models.collection_response_property_group_no_paging import CollectionResponsePropertyGroupNoPaging
from hubspot.crm.properties.models.collection_response_property_no_paging import CollectionResponsePropertyNoPaging
from hubspot.crm.properties.models.error import Error
from hubspot.crm.properties.models.error_detail import ErrorDetail
from hubspot.crm.properties.models.model_property import ModelProperty
from hubspot.crm.properties.models.option import Option
from hubspot.crm.properties.models.option_input import OptionInput
from hubspot.crm.properties.models.property_create import PropertyCreate
from hubspot.crm.properties.models.property_group import PropertyGroup
from hubspot.crm.properties.models.property_group_create import PropertyGroupCreate
from hubspot.crm.properties.models.property_group_update import PropertyGroupUpdate
from hubspot.crm.properties.models.property_modification_metadata import PropertyModificationMetadata
from hubspot.crm.properties.models.property_name import PropertyName
from hubspot.crm.properties.models.property_update import PropertyUpdate
from hubspot.crm.properties.models.standard_error import StandardError



# coding: utf-8

"""
    Crm Owners

    HubSpot uses **owners** to assign CRM objects to specific people in your organization. The endpoints described here are used to get a list of the owners that are available for an account. To assign an owner to an object, set the hubspot_owner_id property using the appropriate CRM object update or create a request.  If teams are available for your HubSpot tier, these endpoints will also indicate which team(s) an owner can access, as well as which team is the owner's primary team.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.owners.configuration import Configuration


class PublicOwner(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "first_name": "str",
        "last_name": "str",
        "created_at": "datetime",
        "archived": "bool",
        "teams": "list[PublicTeam]",
        "id": "str",
        "user_id_including_inactive": "int",
        "type": "str",
        "user_id": "int",
        "email": "str",
        "updated_at": "datetime",
    }

    attribute_map = {
        "first_name": "firstName",
        "last_name": "lastName",
        "created_at": "createdAt",
        "archived": "archived",
        "teams": "teams",
        "id": "id",
        "user_id_including_inactive": "userIdIncludingInactive",
        "type": "type",
        "user_id": "userId",
        "email": "email",
        "updated_at": "updatedAt",
    }

    def __init__(
        self,
        first_name=None,
        last_name=None,
        created_at=None,
        archived=None,
        teams=None,
        id=None,
        user_id_including_inactive=None,
        type=None,
        user_id=None,
        email=None,
        updated_at=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicOwner - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._first_name = None
        self._last_name = None
        self._created_at = None
        self._archived = None
        self._teams = None
        self._id = None
        self._user_id_including_inactive = None
        self._type = None
        self._user_id = None
        self._email = None
        self._updated_at = None
        self.discriminator = None

        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        self.created_at = created_at
        self.archived = archived
        if teams is not None:
            self.teams = teams
        self.id = id
        if user_id_including_inactive is not None:
            self.user_id_including_inactive = user_id_including_inactive
        self.type = type
        if user_id is not None:
            self.user_id = user_id
        if email is not None:
            self.email = email
        self.updated_at = updated_at

    @property
    def first_name(self):
        """Gets the first_name of this PublicOwner.  # noqa: E501


        :return: The first_name of this PublicOwner.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this PublicOwner.


        :param first_name: The first_name of this PublicOwner.  # noqa: E501
        :type first_name: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this PublicOwner.  # noqa: E501


        :return: The last_name of this PublicOwner.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this PublicOwner.


        :param last_name: The last_name of this PublicOwner.  # noqa: E501
        :type last_name: str
        """

        self._last_name = last_name

    @property
    def created_at(self):
        """Gets the created_at of this PublicOwner.  # noqa: E501


        :return: The created_at of this PublicOwner.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PublicOwner.


        :param created_at: The created_at of this PublicOwner.  # noqa: E501
        :type created_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def archived(self):
        """Gets the archived of this PublicOwner.  # noqa: E501


        :return: The archived of this PublicOwner.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this PublicOwner.


        :param archived: The archived of this PublicOwner.  # noqa: E501
        :type archived: bool
        """
        if self.local_vars_configuration.client_side_validation and archived is None:  # noqa: E501
            raise ValueError("Invalid value for `archived`, must not be `None`")  # noqa: E501

        self._archived = archived

    @property
    def teams(self):
        """Gets the teams of this PublicOwner.  # noqa: E501


        :return: The teams of this PublicOwner.  # noqa: E501
        :rtype: list[PublicTeam]
        """
        return self._teams

    @teams.setter
    def teams(self, teams):
        """Sets the teams of this PublicOwner.


        :param teams: The teams of this PublicOwner.  # noqa: E501
        :type teams: list[PublicTeam]
        """

        self._teams = teams

    @property
    def id(self):
        """Gets the id of this PublicOwner.  # noqa: E501


        :return: The id of this PublicOwner.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PublicOwner.


        :param id: The id of this PublicOwner.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id_including_inactive(self):
        """Gets the user_id_including_inactive of this PublicOwner.  # noqa: E501


        :return: The user_id_including_inactive of this PublicOwner.  # noqa: E501
        :rtype: int
        """
        return self._user_id_including_inactive

    @user_id_including_inactive.setter
    def user_id_including_inactive(self, user_id_including_inactive):
        """Sets the user_id_including_inactive of this PublicOwner.


        :param user_id_including_inactive: The user_id_including_inactive of this PublicOwner.  # noqa: E501
        :type user_id_including_inactive: int
        """

        self._user_id_including_inactive = user_id_including_inactive

    @property
    def type(self):
        """Gets the type of this PublicOwner.  # noqa: E501


        :return: The type of this PublicOwner.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PublicOwner.


        :param type: The type of this PublicOwner.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["PERSON", "QUEUE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `type` ({0}), must be one of {1}".format(type, allowed_values))  # noqa: E501

        self._type = type

    @property
    def user_id(self):
        """Gets the user_id of this PublicOwner.  # noqa: E501


        :return: The user_id of this PublicOwner.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this PublicOwner.


        :param user_id: The user_id of this PublicOwner.  # noqa: E501
        :type user_id: int
        """

        self._user_id = user_id

    @property
    def email(self):
        """Gets the email of this PublicOwner.  # noqa: E501


        :return: The email of this PublicOwner.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this PublicOwner.


        :param email: The email of this PublicOwner.  # noqa: E501
        :type email: str
        """

        self._email = email

    @property
    def updated_at(self):
        """Gets the updated_at of this PublicOwner.  # noqa: E501


        :return: The updated_at of this PublicOwner.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this PublicOwner.


        :param updated_at: The updated_at of this PublicOwner.  # noqa: E501
        :type updated_at: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicOwner):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicOwner):
            return True

        return self.to_dict() != other.to_dict()



import hubspot.cms.blogs.blog_posts as api_client
from ....discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def basic_api(self) -> api_client.BasicApi:
        return self._configure_api_client(api_client, "BasicApi")
    @property
    def batch_api(self) -> api_client.BatchApi:
        return self._configure_api_client(api_client, "BatchApi")
    @property
    def multi_language_api(self) -> api_client.MultiLanguageApi:
        return self._configure_api_client(api_client, "MultiLanguageApi")



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from hubspot.crm.timeline.api.events_api import EventsApi
from hubspot.crm.timeline.api.templates_api import TemplatesApi
from hubspot.crm.timeline.api.tokens_api import TokensApi



# coding: utf-8

"""
    Settings User Provisioning

    Add, manage, and remove users from your account  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.settings.users.configuration import Configuration


class UserProvisionRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"primary_team_id": "str", "send_welcome_email": "bool", "role_id": "str", "secondary_team_ids": "list[str]", "email": "str"}

    attribute_map = {"primary_team_id": "primaryTeamId", "send_welcome_email": "sendWelcomeEmail", "role_id": "roleId", "secondary_team_ids": "secondaryTeamIds", "email": "email"}

    def __init__(self, primary_team_id=None, send_welcome_email=None, role_id=None, secondary_team_ids=None, email=None, local_vars_configuration=None):  # noqa: E501
        """UserProvisionRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._primary_team_id = None
        self._send_welcome_email = None
        self._role_id = None
        self._secondary_team_ids = None
        self._email = None
        self.discriminator = None

        if primary_team_id is not None:
            self.primary_team_id = primary_team_id
        if send_welcome_email is not None:
            self.send_welcome_email = send_welcome_email
        if role_id is not None:
            self.role_id = role_id
        if secondary_team_ids is not None:
            self.secondary_team_ids = secondary_team_ids
        self.email = email

    @property
    def primary_team_id(self):
        """Gets the primary_team_id of this UserProvisionRequest.  # noqa: E501

        The user's primary team  # noqa: E501

        :return: The primary_team_id of this UserProvisionRequest.  # noqa: E501
        :rtype: str
        """
        return self._primary_team_id

    @primary_team_id.setter
    def primary_team_id(self, primary_team_id):
        """Sets the primary_team_id of this UserProvisionRequest.

        The user's primary team  # noqa: E501

        :param primary_team_id: The primary_team_id of this UserProvisionRequest.  # noqa: E501
        :type primary_team_id: str
        """

        self._primary_team_id = primary_team_id

    @property
    def send_welcome_email(self):
        """Gets the send_welcome_email of this UserProvisionRequest.  # noqa: E501

        Whether to send a welcome email  # noqa: E501

        :return: The send_welcome_email of this UserProvisionRequest.  # noqa: E501
        :rtype: bool
        """
        return self._send_welcome_email

    @send_welcome_email.setter
    def send_welcome_email(self, send_welcome_email):
        """Sets the send_welcome_email of this UserProvisionRequest.

        Whether to send a welcome email  # noqa: E501

        :param send_welcome_email: The send_welcome_email of this UserProvisionRequest.  # noqa: E501
        :type send_welcome_email: bool
        """

        self._send_welcome_email = send_welcome_email

    @property
    def role_id(self):
        """Gets the role_id of this UserProvisionRequest.  # noqa: E501

        The user's role  # noqa: E501

        :return: The role_id of this UserProvisionRequest.  # noqa: E501
        :rtype: str
        """
        return self._role_id

    @role_id.setter
    def role_id(self, role_id):
        """Sets the role_id of this UserProvisionRequest.

        The user's role  # noqa: E501

        :param role_id: The role_id of this UserProvisionRequest.  # noqa: E501
        :type role_id: str
        """

        self._role_id = role_id

    @property
    def secondary_team_ids(self):
        """Gets the secondary_team_ids of this UserProvisionRequest.  # noqa: E501

        The user's additional teams  # noqa: E501

        :return: The secondary_team_ids of this UserProvisionRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._secondary_team_ids

    @secondary_team_ids.setter
    def secondary_team_ids(self, secondary_team_ids):
        """Sets the secondary_team_ids of this UserProvisionRequest.

        The user's additional teams  # noqa: E501

        :param secondary_team_ids: The secondary_team_ids of this UserProvisionRequest.  # noqa: E501
        :type secondary_team_ids: list[str]
        """

        self._secondary_team_ids = secondary_team_ids

    @property
    def email(self):
        """Gets the email of this UserProvisionRequest.  # noqa: E501

        The created user's email  # noqa: E501

        :return: The email of this UserProvisionRequest.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this UserProvisionRequest.

        The created user's email  # noqa: E501

        :param email: The email of this UserProvisionRequest.  # noqa: E501
        :type email: str
        """
        if self.local_vars_configuration.client_side_validation and email is None:  # noqa: E501
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserProvisionRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserProvisionRequest):
            return True

        return self.to_dict() != other.to_dict()



import hubspot.crm.timeline as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def events_api(self) -> api_client.EventsApi:
        return self._configure_api_client(api_client, "EventsApi")

    @property
    def templates_api(self) -> api_client.TemplatesApi:
        return self._configure_api_client(api_client, "TemplatesApi")

    @property
    def tokens_api(self) -> api_client.TokensApi:
        return self._configure_api_client(api_client, "TokensApi")



# coding: utf-8

# flake8: noqa
"""
    Associations

    Associations define the relationships between objects in HubSpot. These endpoints allow you to create, read, and remove associations.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.crm.associations.models.associated_id import AssociatedId
from hubspot.crm.associations.models.batch_input_public_association import BatchInputPublicAssociation
from hubspot.crm.associations.models.batch_input_public_object_id import BatchInputPublicObjectId
from hubspot.crm.associations.models.batch_response_public_association import BatchResponsePublicAssociation
from hubspot.crm.associations.models.batch_response_public_association_multi import BatchResponsePublicAssociationMulti
from hubspot.crm.associations.models.batch_response_public_association_multi_with_errors import BatchResponsePublicAssociationMultiWithErrors
from hubspot.crm.associations.models.batch_response_public_association_with_errors import BatchResponsePublicAssociationWithErrors
from hubspot.crm.associations.models.error import Error
from hubspot.crm.associations.models.error_detail import ErrorDetail
from hubspot.crm.associations.models.next_page import NextPage
from hubspot.crm.associations.models.paging import Paging
from hubspot.crm.associations.models.previous_page import PreviousPage
from hubspot.crm.associations.models.public_association import PublicAssociation
from hubspot.crm.associations.models.public_association_multi import PublicAssociationMulti
from hubspot.crm.associations.models.public_object_id import PublicObjectId
from hubspot.crm.associations.models.standard_error import StandardError



# coding: utf-8

# flake8: noqa
"""
    Auth Oauth

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.oauth.models.access_token_info_response import AccessTokenInfoResponse
from hubspot.oauth.models.error import Error
from hubspot.oauth.models.error_detail import ErrorDetail
from hubspot.oauth.models.refresh_token_info_response import RefreshTokenInfoResponse
from hubspot.oauth.models.token_response_if import TokenResponseIF



# coding: utf-8

# flake8: noqa
"""
    Communication Preferences Subscriptions

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.communication_preferences.models.error import Error
from hubspot.communication_preferences.models.error_detail import ErrorDetail
from hubspot.communication_preferences.models.public_subscription_status import PublicSubscriptionStatus
from hubspot.communication_preferences.models.public_subscription_statuses_response import PublicSubscriptionStatusesResponse
from hubspot.communication_preferences.models.public_update_subscription_status_request import PublicUpdateSubscriptionStatusRequest
from hubspot.communication_preferences.models.subscription_definition import SubscriptionDefinition
from hubspot.communication_preferences.models.subscription_definitions_response import SubscriptionDefinitionsResponse



# coding: utf-8

# flake8: noqa
"""
    Visitor Identification

    The Visitor Identification API allows you to pass identification information to the HubSpot chat widget for otherwise unknown visitors that were verified by your own authentication system.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.conversations.visitor_identification.models.error import Error
from hubspot.conversations.visitor_identification.models.error_detail import ErrorDetail
from hubspot.conversations.visitor_identification.models.identification_token_generation_request import IdentificationTokenGenerationRequest
from hubspot.conversations.visitor_identification.models.identification_token_response import IdentificationTokenResponse



# coding: utf-8

"""
    Marketing Events

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.events.configuration import Configuration


class PublicList(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "processing_type": "str",
        "object_type_id": "str",
        "updated_by_id": "str",
        "filters_updated_at": "datetime",
        "list_id": "str",
        "created_at": "datetime",
        "processing_status": "str",
        "deleted_at": "datetime",
        "list_version": "int",
        "size": "int",
        "name": "str",
        "created_by_id": "str",
        "updated_at": "datetime",
    }

    attribute_map = {
        "processing_type": "processingType",
        "object_type_id": "objectTypeId",
        "updated_by_id": "updatedById",
        "filters_updated_at": "filtersUpdatedAt",
        "list_id": "listId",
        "created_at": "createdAt",
        "processing_status": "processingStatus",
        "deleted_at": "deletedAt",
        "list_version": "listVersion",
        "size": "size",
        "name": "name",
        "created_by_id": "createdById",
        "updated_at": "updatedAt",
    }

    def __init__(
        self,
        processing_type=None,
        object_type_id=None,
        updated_by_id=None,
        filters_updated_at=None,
        list_id=None,
        created_at=None,
        processing_status=None,
        deleted_at=None,
        list_version=None,
        size=None,
        name=None,
        created_by_id=None,
        updated_at=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicList - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._processing_type = None
        self._object_type_id = None
        self._updated_by_id = None
        self._filters_updated_at = None
        self._list_id = None
        self._created_at = None
        self._processing_status = None
        self._deleted_at = None
        self._list_version = None
        self._size = None
        self._name = None
        self._created_by_id = None
        self._updated_at = None
        self.discriminator = None

        self.processing_type = processing_type
        self.object_type_id = object_type_id
        if updated_by_id is not None:
            self.updated_by_id = updated_by_id
        if filters_updated_at is not None:
            self.filters_updated_at = filters_updated_at
        self.list_id = list_id
        if created_at is not None:
            self.created_at = created_at
        self.processing_status = processing_status
        if deleted_at is not None:
            self.deleted_at = deleted_at
        self.list_version = list_version
        if size is not None:
            self.size = size
        self.name = name
        if created_by_id is not None:
            self.created_by_id = created_by_id
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def processing_type(self):
        """Gets the processing_type of this PublicList.  # noqa: E501


        :return: The processing_type of this PublicList.  # noqa: E501
        :rtype: str
        """
        return self._processing_type

    @processing_type.setter
    def processing_type(self, processing_type):
        """Sets the processing_type of this PublicList.


        :param processing_type: The processing_type of this PublicList.  # noqa: E501
        :type processing_type: str
        """
        if self.local_vars_configuration.client_side_validation and processing_type is None:  # noqa: E501
            raise ValueError("Invalid value for `processing_type`, must not be `None`")  # noqa: E501

        self._processing_type = processing_type

    @property
    def object_type_id(self):
        """Gets the object_type_id of this PublicList.  # noqa: E501


        :return: The object_type_id of this PublicList.  # noqa: E501
        :rtype: str
        """
        return self._object_type_id

    @object_type_id.setter
    def object_type_id(self, object_type_id):
        """Sets the object_type_id of this PublicList.


        :param object_type_id: The object_type_id of this PublicList.  # noqa: E501
        :type object_type_id: str
        """
        if self.local_vars_configuration.client_side_validation and object_type_id is None:  # noqa: E501
            raise ValueError("Invalid value for `object_type_id`, must not be `None`")  # noqa: E501

        self._object_type_id = object_type_id

    @property
    def updated_by_id(self):
        """Gets the updated_by_id of this PublicList.  # noqa: E501


        :return: The updated_by_id of this PublicList.  # noqa: E501
        :rtype: str
        """
        return self._updated_by_id

    @updated_by_id.setter
    def updated_by_id(self, updated_by_id):
        """Sets the updated_by_id of this PublicList.


        :param updated_by_id: The updated_by_id of this PublicList.  # noqa: E501
        :type updated_by_id: str
        """

        self._updated_by_id = updated_by_id

    @property
    def filters_updated_at(self):
        """Gets the filters_updated_at of this PublicList.  # noqa: E501


        :return: The filters_updated_at of this PublicList.  # noqa: E501
        :rtype: datetime
        """
        return self._filters_updated_at

    @filters_updated_at.setter
    def filters_updated_at(self, filters_updated_at):
        """Sets the filters_updated_at of this PublicList.


        :param filters_updated_at: The filters_updated_at of this PublicList.  # noqa: E501
        :type filters_updated_at: datetime
        """

        self._filters_updated_at = filters_updated_at

    @property
    def list_id(self):
        """Gets the list_id of this PublicList.  # noqa: E501


        :return: The list_id of this PublicList.  # noqa: E501
        :rtype: str
        """
        return self._list_id

    @list_id.setter
    def list_id(self, list_id):
        """Sets the list_id of this PublicList.


        :param list_id: The list_id of this PublicList.  # noqa: E501
        :type list_id: str
        """
        if self.local_vars_configuration.client_side_validation and list_id is None:  # noqa: E501
            raise ValueError("Invalid value for `list_id`, must not be `None`")  # noqa: E501

        self._list_id = list_id

    @property
    def created_at(self):
        """Gets the created_at of this PublicList.  # noqa: E501


        :return: The created_at of this PublicList.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PublicList.


        :param created_at: The created_at of this PublicList.  # noqa: E501
        :type created_at: datetime
        """

        self._created_at = created_at

    @property
    def processing_status(self):
        """Gets the processing_status of this PublicList.  # noqa: E501


        :return: The processing_status of this PublicList.  # noqa: E501
        :rtype: str
        """
        return self._processing_status

    @processing_status.setter
    def processing_status(self, processing_status):
        """Sets the processing_status of this PublicList.


        :param processing_status: The processing_status of this PublicList.  # noqa: E501
        :type processing_status: str
        """
        if self.local_vars_configuration.client_side_validation and processing_status is None:  # noqa: E501
            raise ValueError("Invalid value for `processing_status`, must not be `None`")  # noqa: E501

        self._processing_status = processing_status

    @property
    def deleted_at(self):
        """Gets the deleted_at of this PublicList.  # noqa: E501


        :return: The deleted_at of this PublicList.  # noqa: E501
        :rtype: datetime
        """
        return self._deleted_at

    @deleted_at.setter
    def deleted_at(self, deleted_at):
        """Sets the deleted_at of this PublicList.


        :param deleted_at: The deleted_at of this PublicList.  # noqa: E501
        :type deleted_at: datetime
        """

        self._deleted_at = deleted_at

    @property
    def list_version(self):
        """Gets the list_version of this PublicList.  # noqa: E501


        :return: The list_version of this PublicList.  # noqa: E501
        :rtype: int
        """
        return self._list_version

    @list_version.setter
    def list_version(self, list_version):
        """Sets the list_version of this PublicList.


        :param list_version: The list_version of this PublicList.  # noqa: E501
        :type list_version: int
        """
        if self.local_vars_configuration.client_side_validation and list_version is None:  # noqa: E501
            raise ValueError("Invalid value for `list_version`, must not be `None`")  # noqa: E501

        self._list_version = list_version

    @property
    def size(self):
        """Gets the size of this PublicList.  # noqa: E501


        :return: The size of this PublicList.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this PublicList.


        :param size: The size of this PublicList.  # noqa: E501
        :type size: int
        """

        self._size = size

    @property
    def name(self):
        """Gets the name of this PublicList.  # noqa: E501


        :return: The name of this PublicList.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PublicList.


        :param name: The name of this PublicList.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def created_by_id(self):
        """Gets the created_by_id of this PublicList.  # noqa: E501


        :return: The created_by_id of this PublicList.  # noqa: E501
        :rtype: str
        """
        return self._created_by_id

    @created_by_id.setter
    def created_by_id(self, created_by_id):
        """Sets the created_by_id of this PublicList.


        :param created_by_id: The created_by_id of this PublicList.  # noqa: E501
        :type created_by_id: str
        """

        self._created_by_id = created_by_id

    @property
    def updated_at(self):
        """Gets the updated_at of this PublicList.  # noqa: E501


        :return: The updated_at of this PublicList.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this PublicList.


        :param updated_at: The updated_at of this PublicList.  # noqa: E501
        :type updated_at: datetime
        """

        self._updated_at = updated_at

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicList):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicList):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Marketing Emails

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.marketing.emails.api.marketing_emails_api import MarketingEmailsApi
from hubspot.marketing.emails.api.statistics_api import StatisticsApi

# import ApiClient
from hubspot.marketing.emails.api_client import ApiClient
from hubspot.marketing.emails.configuration import Configuration
from hubspot.marketing.emails.exceptions import OpenApiException
from hubspot.marketing.emails.exceptions import ApiTypeError
from hubspot.marketing.emails.exceptions import ApiValueError
from hubspot.marketing.emails.exceptions import ApiKeyError
from hubspot.marketing.emails.exceptions import ApiAttributeError
from hubspot.marketing.emails.exceptions import ApiException

# import models into sdk package
from hubspot.marketing.emails.models.ab_test_create_request_v_next import AbTestCreateRequestVNext
from hubspot.marketing.emails.models.aggregate_email_statistics import AggregateEmailStatistics
from hubspot.marketing.emails.models.collection_response_with_total_email_statistic_interval_no_paging import CollectionResponseWithTotalEmailStatisticIntervalNoPaging
from hubspot.marketing.emails.models.collection_response_with_total_public_email_forward_paging import CollectionResponseWithTotalPublicEmailForwardPaging
from hubspot.marketing.emails.models.collection_response_with_total_version_public_email import CollectionResponseWithTotalVersionPublicEmail
from hubspot.marketing.emails.models.content_clone_request_v_next import ContentCloneRequestVNext
from hubspot.marketing.emails.models.email_create_request import EmailCreateRequest
from hubspot.marketing.emails.models.email_statistic_interval import EmailStatisticInterval
from hubspot.marketing.emails.models.email_statistics_data import EmailStatisticsData
from hubspot.marketing.emails.models.email_update_request import EmailUpdateRequest
from hubspot.marketing.emails.models.error import Error
from hubspot.marketing.emails.models.error_detail import ErrorDetail
from hubspot.marketing.emails.models.forward_paging import ForwardPaging
from hubspot.marketing.emails.models.interval import Interval
from hubspot.marketing.emails.models.next_page import NextPage
from hubspot.marketing.emails.models.paging import Paging
from hubspot.marketing.emails.models.previous_page import PreviousPage
from hubspot.marketing.emails.models.public_button_style_settings import PublicButtonStyleSettings
from hubspot.marketing.emails.models.public_divider_style_settings import PublicDividerStyleSettings
from hubspot.marketing.emails.models.public_email import PublicEmail
from hubspot.marketing.emails.models.public_email_content import PublicEmailContent
from hubspot.marketing.emails.models.public_email_from_details import PublicEmailFromDetails
from hubspot.marketing.emails.models.public_email_recipients import PublicEmailRecipients
from hubspot.marketing.emails.models.public_email_style_settings import PublicEmailStyleSettings
from hubspot.marketing.emails.models.public_email_subscription_details import PublicEmailSubscriptionDetails
from hubspot.marketing.emails.models.public_email_testing_details import PublicEmailTestingDetails
from hubspot.marketing.emails.models.public_email_to_details import PublicEmailToDetails
from hubspot.marketing.emails.models.public_font_style import PublicFontStyle
from hubspot.marketing.emails.models.public_rss_email_details import PublicRssEmailDetails
from hubspot.marketing.emails.models.public_webversion_details import PublicWebversionDetails
from hubspot.marketing.emails.models.version_public_email import VersionPublicEmail
from hubspot.marketing.emails.models.version_user import VersionUser



# coding: utf-8

"""
    Automation Actions V4

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v4
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.automation.actions.configuration import Configuration


class PublicActionDefinitionEgg(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "input_fields": "list[InputFieldDefinition]",
        "output_fields": "list[OutputFieldDefinition]",
        "archived_at": "int",
        "functions": "list[PublicActionFunction]",
        "action_url": "str",
        "input_field_dependencies": "list[PublicActionDefinitionInputFieldDependenciesInner]",
        "published": "bool",
        "execution_rules": "list[PublicExecutionTranslationRule]",
        "object_types": "list[str]",
        "object_request_options": "PublicObjectRequestOptions",
        "labels": "dict[str, PublicActionLabels]",
    }

    attribute_map = {
        "input_fields": "inputFields",
        "output_fields": "outputFields",
        "archived_at": "archivedAt",
        "functions": "functions",
        "action_url": "actionUrl",
        "input_field_dependencies": "inputFieldDependencies",
        "published": "published",
        "execution_rules": "executionRules",
        "object_types": "objectTypes",
        "object_request_options": "objectRequestOptions",
        "labels": "labels",
    }

    def __init__(
        self,
        input_fields=None,
        output_fields=None,
        archived_at=None,
        functions=None,
        action_url=None,
        input_field_dependencies=None,
        published=None,
        execution_rules=None,
        object_types=None,
        object_request_options=None,
        labels=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicActionDefinitionEgg - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._input_fields = None
        self._output_fields = None
        self._archived_at = None
        self._functions = None
        self._action_url = None
        self._input_field_dependencies = None
        self._published = None
        self._execution_rules = None
        self._object_types = None
        self._object_request_options = None
        self._labels = None
        self.discriminator = None

        self.input_fields = input_fields
        if output_fields is not None:
            self.output_fields = output_fields
        if archived_at is not None:
            self.archived_at = archived_at
        self.functions = functions
        self.action_url = action_url
        if input_field_dependencies is not None:
            self.input_field_dependencies = input_field_dependencies
        self.published = published
        if execution_rules is not None:
            self.execution_rules = execution_rules
        self.object_types = object_types
        if object_request_options is not None:
            self.object_request_options = object_request_options
        self.labels = labels

    @property
    def input_fields(self):
        """Gets the input_fields of this PublicActionDefinitionEgg.  # noqa: E501


        :return: The input_fields of this PublicActionDefinitionEgg.  # noqa: E501
        :rtype: list[InputFieldDefinition]
        """
        return self._input_fields

    @input_fields.setter
    def input_fields(self, input_fields):
        """Sets the input_fields of this PublicActionDefinitionEgg.


        :param input_fields: The input_fields of this PublicActionDefinitionEgg.  # noqa: E501
        :type input_fields: list[InputFieldDefinition]
        """
        if self.local_vars_configuration.client_side_validation and input_fields is None:  # noqa: E501
            raise ValueError("Invalid value for `input_fields`, must not be `None`")  # noqa: E501

        self._input_fields = input_fields

    @property
    def output_fields(self):
        """Gets the output_fields of this PublicActionDefinitionEgg.  # noqa: E501


        :return: The output_fields of this PublicActionDefinitionEgg.  # noqa: E501
        :rtype: list[OutputFieldDefinition]
        """
        return self._output_fields

    @output_fields.setter
    def output_fields(self, output_fields):
        """Sets the output_fields of this PublicActionDefinitionEgg.


        :param output_fields: The output_fields of this PublicActionDefinitionEgg.  # noqa: E501
        :type output_fields: list[OutputFieldDefinition]
        """

        self._output_fields = output_fields

    @property
    def archived_at(self):
        """Gets the archived_at of this PublicActionDefinitionEgg.  # noqa: E501


        :return: The archived_at of this PublicActionDefinitionEgg.  # noqa: E501
        :rtype: int
        """
        return self._archived_at

    @archived_at.setter
    def archived_at(self, archived_at):
        """Sets the archived_at of this PublicActionDefinitionEgg.


        :param archived_at: The archived_at of this PublicActionDefinitionEgg.  # noqa: E501
        :type archived_at: int
        """

        self._archived_at = archived_at

    @property
    def functions(self):
        """Gets the functions of this PublicActionDefinitionEgg.  # noqa: E501


        :return: The functions of this PublicActionDefinitionEgg.  # noqa: E501
        :rtype: list[PublicActionFunction]
        """
        return self._functions

    @functions.setter
    def functions(self, functions):
        """Sets the functions of this PublicActionDefinitionEgg.


        :param functions: The functions of this PublicActionDefinitionEgg.  # noqa: E501
        :type functions: list[PublicActionFunction]
        """
        if self.local_vars_configuration.client_side_validation and functions is None:  # noqa: E501
            raise ValueError("Invalid value for `functions`, must not be `None`")  # noqa: E501

        self._functions = functions

    @property
    def action_url(self):
        """Gets the action_url of this PublicActionDefinitionEgg.  # noqa: E501


        :return: The action_url of this PublicActionDefinitionEgg.  # noqa: E501
        :rtype: str
        """
        return self._action_url

    @action_url.setter
    def action_url(self, action_url):
        """Sets the action_url of this PublicActionDefinitionEgg.


        :param action_url: The action_url of this PublicActionDefinitionEgg.  # noqa: E501
        :type action_url: str
        """
        if self.local_vars_configuration.client_side_validation and action_url is None:  # noqa: E501
            raise ValueError("Invalid value for `action_url`, must not be `None`")  # noqa: E501

        self._action_url = action_url

    @property
    def input_field_dependencies(self):
        """Gets the input_field_dependencies of this PublicActionDefinitionEgg.  # noqa: E501


        :return: The input_field_dependencies of this PublicActionDefinitionEgg.  # noqa: E501
        :rtype: list[PublicActionDefinitionInputFieldDependenciesInner]
        """
        return self._input_field_dependencies

    @input_field_dependencies.setter
    def input_field_dependencies(self, input_field_dependencies):
        """Sets the input_field_dependencies of this PublicActionDefinitionEgg.


        :param input_field_dependencies: The input_field_dependencies of this PublicActionDefinitionEgg.  # noqa: E501
        :type input_field_dependencies: list[PublicActionDefinitionInputFieldDependenciesInner]
        """

        self._input_field_dependencies = input_field_dependencies

    @property
    def published(self):
        """Gets the published of this PublicActionDefinitionEgg.  # noqa: E501


        :return: The published of this PublicActionDefinitionEgg.  # noqa: E501
        :rtype: bool
        """
        return self._published

    @published.setter
    def published(self, published):
        """Sets the published of this PublicActionDefinitionEgg.


        :param published: The published of this PublicActionDefinitionEgg.  # noqa: E501
        :type published: bool
        """
        if self.local_vars_configuration.client_side_validation and published is None:  # noqa: E501
            raise ValueError("Invalid value for `published`, must not be `None`")  # noqa: E501

        self._published = published

    @property
    def execution_rules(self):
        """Gets the execution_rules of this PublicActionDefinitionEgg.  # noqa: E501


        :return: The execution_rules of this PublicActionDefinitionEgg.  # noqa: E501
        :rtype: list[PublicExecutionTranslationRule]
        """
        return self._execution_rules

    @execution_rules.setter
    def execution_rules(self, execution_rules):
        """Sets the execution_rules of this PublicActionDefinitionEgg.


        :param execution_rules: The execution_rules of this PublicActionDefinitionEgg.  # noqa: E501
        :type execution_rules: list[PublicExecutionTranslationRule]
        """

        self._execution_rules = execution_rules

    @property
    def object_types(self):
        """Gets the object_types of this PublicActionDefinitionEgg.  # noqa: E501


        :return: The object_types of this PublicActionDefinitionEgg.  # noqa: E501
        :rtype: list[str]
        """
        return self._object_types

    @object_types.setter
    def object_types(self, object_types):
        """Sets the object_types of this PublicActionDefinitionEgg.


        :param object_types: The object_types of this PublicActionDefinitionEgg.  # noqa: E501
        :type object_types: list[str]
        """
        if self.local_vars_configuration.client_side_validation and object_types is None:  # noqa: E501
            raise ValueError("Invalid value for `object_types`, must not be `None`")  # noqa: E501

        self._object_types = object_types

    @property
    def object_request_options(self):
        """Gets the object_request_options of this PublicActionDefinitionEgg.  # noqa: E501


        :return: The object_request_options of this PublicActionDefinitionEgg.  # noqa: E501
        :rtype: PublicObjectRequestOptions
        """
        return self._object_request_options

    @object_request_options.setter
    def object_request_options(self, object_request_options):
        """Sets the object_request_options of this PublicActionDefinitionEgg.


        :param object_request_options: The object_request_options of this PublicActionDefinitionEgg.  # noqa: E501
        :type object_request_options: PublicObjectRequestOptions
        """

        self._object_request_options = object_request_options

    @property
    def labels(self):
        """Gets the labels of this PublicActionDefinitionEgg.  # noqa: E501


        :return: The labels of this PublicActionDefinitionEgg.  # noqa: E501
        :rtype: dict[str, PublicActionLabels]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this PublicActionDefinitionEgg.


        :param labels: The labels of this PublicActionDefinitionEgg.  # noqa: E501
        :type labels: dict[str, PublicActionLabels]
        """
        if self.local_vars_configuration.client_side_validation and labels is None:  # noqa: E501
            raise ValueError("Invalid value for `labels`, must not be `None`")  # noqa: E501

        self._labels = labels

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicActionDefinitionEgg):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicActionDefinitionEgg):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    Events Send Event Completions

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.events.send.models.batched_behavioral_event_http_completion_request import BatchedBehavioralEventHttpCompletionRequest
from hubspot.events.send.models.behavioral_event_http_completion_request import BehavioralEventHttpCompletionRequest
from hubspot.events.send.models.error import Error
from hubspot.events.send.models.error_detail import ErrorDetail



import hubspot.cms.hubdb as api_client
from ...discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):
    @property
    def rows_api(self) -> api_client.RowsApi:
        return self._configure_api_client(api_client, "RowsApi")

    @property
    def rows_batch_api(self) -> api_client.RowsBatchApi:
        return self._configure_api_client(api_client, "RowsBatchApi")

    @property
    def tables_api(self) -> api_client.TablesApi:
        return self._configure_api_client(api_client, "TablesApi")



# flake8: noqa

# import apis into api package
from hubspot.conversations.conversations.api.actors_api import ActorsApi
from hubspot.conversations.conversations.api.channel_accounts_api import ChannelAccountsApi
from hubspot.conversations.conversations.api.channels_api import ChannelsApi
from hubspot.conversations.conversations.api.inboxes_api import InboxesApi
from hubspot.conversations.conversations.api.threads_api import ThreadsApi




# coding: utf-8

"""
    Events Events

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.events.api_client import ApiClient
from hubspot.events.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class EventsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_page(self, **kwargs):  # noqa: E501
        """Retrieve event data  # noqa: E501

        Retrieve instances of event completion data. For example, retrieve all event completions associated with a specific contact.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_page(async_req=True)
        >>> result = thread.get()

        :param object_type: The type of CRM object to filter event instances on (e.g., `contact`). To retrieve event data for a specific CRM record, include the additional `objectId` query parameter (below).
        :type object_type: str
        :param event_type: The event type name. You can retrieve available event types using the [event types endpoint](#get-%2Fevents%2Fv3%2Fevents%2Fevent-types).
        :type event_type: str
        :param after: The paging cursor token of the last successfully read resource will be returned as the `paging.next.after` JSON property of a paged response containing more results.
        :type after: str
        :param before:
        :type before: str
        :param limit: The maximum number of results to display per page.
        :type limit: int
        :param sort: Sort direction based on the timestamp of the event instance, `ASCENDING` or `DESCENDING`.
        :type sort: list[str]
        :param occurred_after: Filter for event data that occurred after a specific datetime.
        :type occurred_after: datetime
        :param occurred_before: Filter for event data that occurred before a specific datetime.
        :type occurred_before: datetime
        :param object_id: The ID of the CRM Object to filter event instances on. When including this parameter, you must also include the `objectType` parameter.
        :type object_id: int
        :param object_property_propname: Instead of retrieving event data for a specific object by its ID, you can specify a unique identifier property. For contacts, you can use the `email` property. (e.g., `objectProperty.email=name@domain.com`).
        :type object_property_propname: object
        :param property_propname: Filter for event completions that contain a specific value for an event property (e.g., `property.hs_city=portland`). For properties values with spaces, replaces spaces with `%20` or `+` (e.g., `property.hs_city=new+york`).
        :type property_propname: object
        :param id: ID of an event instance. IDs are 1:1 with event instances. If you provide this filter and additional filters, the other filters must match the values on the event instance to yield results.
        :type id: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CollectionResponseExternalUnifiedEvent
        """
        kwargs["_return_http_data_only"] = True
        return self.get_page_with_http_info(**kwargs)  # noqa: E501

    def get_page_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve event data  # noqa: E501

        Retrieve instances of event completion data. For example, retrieve all event completions associated with a specific contact.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_page_with_http_info(async_req=True)
        >>> result = thread.get()

        :param object_type: The type of CRM object to filter event instances on (e.g., `contact`). To retrieve event data for a specific CRM record, include the additional `objectId` query parameter (below).
        :type object_type: str
        :param event_type: The event type name. You can retrieve available event types using the [event types endpoint](#get-%2Fevents%2Fv3%2Fevents%2Fevent-types).
        :type event_type: str
        :param after: The paging cursor token of the last successfully read resource will be returned as the `paging.next.after` JSON property of a paged response containing more results.
        :type after: str
        :param before:
        :type before: str
        :param limit: The maximum number of results to display per page.
        :type limit: int
        :param sort: Sort direction based on the timestamp of the event instance, `ASCENDING` or `DESCENDING`.
        :type sort: list[str]
        :param occurred_after: Filter for event data that occurred after a specific datetime.
        :type occurred_after: datetime
        :param occurred_before: Filter for event data that occurred before a specific datetime.
        :type occurred_before: datetime
        :param object_id: The ID of the CRM Object to filter event instances on. When including this parameter, you must also include the `objectType` parameter.
        :type object_id: int
        :param object_property_propname: Instead of retrieving event data for a specific object by its ID, you can specify a unique identifier property. For contacts, you can use the `email` property. (e.g., `objectProperty.email=name@domain.com`).
        :type object_property_propname: object
        :param property_propname: Filter for event completions that contain a specific value for an event property (e.g., `property.hs_city=portland`). For properties values with spaces, replaces spaces with `%20` or `+` (e.g., `property.hs_city=new+york`).
        :type property_propname: object
        :param id: ID of an event instance. IDs are 1:1 with event instances. If you provide this filter and additional filters, the other filters must match the values on the event instance to yield results.
        :type id: list[str]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CollectionResponseExternalUnifiedEvent, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["object_type", "event_type", "after", "before", "limit", "sort", "occurred_after", "occurred_before", "object_id", "object_property_propname", "property_propname", "id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_page" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if local_var_params.get("object_type") is not None:  # noqa: E501
            query_params.append(("objectType", local_var_params["object_type"]))  # noqa: E501
        if local_var_params.get("event_type") is not None:  # noqa: E501
            query_params.append(("eventType", local_var_params["event_type"]))  # noqa: E501
        if local_var_params.get("after") is not None:  # noqa: E501
            query_params.append(("after", local_var_params["after"]))  # noqa: E501
        if local_var_params.get("before") is not None:  # noqa: E501
            query_params.append(("before", local_var_params["before"]))  # noqa: E501
        if local_var_params.get("limit") is not None:  # noqa: E501
            query_params.append(("limit", local_var_params["limit"]))  # noqa: E501
        if local_var_params.get("sort") is not None:  # noqa: E501
            query_params.append(("sort", local_var_params["sort"]))  # noqa: E501
            collection_formats["sort"] = "multi"  # noqa: E501
        if local_var_params.get("occurred_after") is not None:  # noqa: E501
            query_params.append(("occurredAfter", local_var_params["occurred_after"]))  # noqa: E501
        if local_var_params.get("occurred_before") is not None:  # noqa: E501
            query_params.append(("occurredBefore", local_var_params["occurred_before"]))  # noqa: E501
        if local_var_params.get("object_id") is not None:  # noqa: E501
            query_params.append(("objectId", local_var_params["object_id"]))  # noqa: E501
        if local_var_params.get("object_property_propname") is not None:  # noqa: E501
            query_params.append(("objectProperty.{propname}", local_var_params["object_property_propname"]))  # noqa: E501
        if local_var_params.get("property_propname") is not None:  # noqa: E501
            query_params.append(("property.{propname}", local_var_params["property_propname"]))  # noqa: E501
        if local_var_params.get("id") is not None:  # noqa: E501
            query_params.append(("id", local_var_params["id"]))  # noqa: E501
            collection_formats["id"] = "multi"  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "CollectionResponseExternalUnifiedEvent",
        }

        return self.api_client.call_api(
            "/events/v3/events/",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_types(self, **kwargs):  # noqa: E501
        """Event Types  # noqa: E501

        This endpoint returns a list of event type names which are visible to you. You may use these event type names to query the API for specific event instances of a desired type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_types(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: VisibleExternalEventTypeNames
        """
        kwargs["_return_http_data_only"] = True
        return self.get_types_with_http_info(**kwargs)  # noqa: E501

    def get_types_with_http_info(self, **kwargs):  # noqa: E501
        """Event Types  # noqa: E501

        This endpoint returns a list of event type names which are visible to you. You may use these event type names to query the API for specific event instances of a desired type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_types_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(VisibleExternalEventTypeNames, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = []
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_types" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "VisibleExternalEventTypeNames",
        }

        return self.api_client.call_api(
            "/events/v3/events/event-types",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )
